local addonName, addon = ...
local L = LibStub('AceLocale-3.0'):GetLocale('Groupie')

--Update this with each push to curse, this will be used for version checks
addon.version = tonumber(GetAddOnMetadata(addonName, "Version"))

--Used for storing the merged friend and ignore lists of all characters
addon.friendList = {}
addon.ignoreList = {}

--Sounds for group alerts
addon.sounds = {
    [17318] = "LFG-DungeonReady"
}

--Toggle for 'LFG mode', which disables or enables auto responses and alert sounds
addon.LFGMode = false

--Cached Item level calculations by GUID for current session
addon.ILVLCache = {}
addon.playerILVL = nil
addon.playerGearScore = nil
addon.playerGearScoreColor = nil

--Message formats for various checked messages
addon.askForPlayerInfo = format("{rt3} %s : What Role are you?", addonName)
addon.askForInstance = format("{rt3} %s : What are you inviting me to?", addonName)
addon.autoRejectRequestString = "FYI, I have Auto-Reject enabled. Message me back and if it's a good fit I'll send you an invite. Thanks!"
addon.autoRejectInviteString = "FYI, I have Auto-Reject enabled. Message me back and if it's a good fit I'll come. Thanks!"
addon.instanceResetString = format("{rt3} %s : All Instances Have Been Reset!", addonName)
addon.PROTECTED_TOKENS = {
    [1] = "%s*{rt3}%s*groupie%s*:",
    [2] = "%s*groupie%s*{rt3}%s*:",
    [3] = "%s*{diamond}%s*groupie%s*:",
    [4] = "%s*groupie%s*{diamond}%s*:",
}
addon.WARNING_MESSAGE = "{rt3} Groupie : Fake News! That is not a real Groupie Message. Quit being shady."

--Supported localizations, we only load the addon for these
addon.validLocales = { "enGB", "enUS" }
--Localizations for which we have all the saved instance data
--shows minimap prompt asking users to submit to the discord if their locale is not here
addon.completedLocales = { "enGB", "enUS" }

addon.groupieSystemColor = "ffd900"
addon.groupieSystemColorR = 255
addon.groupieSystemColorG = 217
addon.groupieSystemColorB = 0

addon.groupieLocaleTable = {
    ["zhCN"] = "Chinese",
    ["zhTW"] = "Chinese",
    ["enGB"] = "English",
    ["enUS"] = "English",
    ["frFR"] = "French",
    ["deDE"] = "German",
    ["itIT"] = "Italian",
    ["koKR"] = "Korean",
    ["ptBR"] = "Portuguese",
    ["ruRU"] = "Russian",
    ["esES"] = "Spanish",
    ["esMX"] = "Spanish",
}

addon.localeCodes = {
    ["zhCN"] = "ZH",
    ["zhTW"] = "ZH",
    ["enGB"] = "EN",
    ["enUS"] = "EN",
    ["frFR"] = "FR",
    ["deDE"] = "DE",
    ["itIT"] = "IT",
    ["koKR"] = "KO",
    ["ptBR"] = "PT",
    ["ruRU"] = "RU",
    ["esES"] = "ES",
    ["esMX"] = "ES",
}

--For now, this only supports English, but implemented such that localization would be easy in the future
--https://en.wikipedia.org/wiki/List_of_ISO_639-2_codes Language Codes
--https://en.wikipedia.org/wiki/ISO_3166-2 Country Codes
addon.groupieUnflippedLanguagePatterns = {
    ["Chinese"]    = "chinese zho chi zh",
    ["English"]    = "english eng en",
    ["French"]     = "french fra fr",
    ["German"]     = "german deu ger de",
    ["Italian"]    = "italian ita it",
    ["Korean"]     = "korean kor ko",
    ["Portuguese"] = "portuguese por pt br",
    ["Russian"]    = "russian rus ru",
    ["Spanish"]    = "spanish spa es",
}

addon.groupieLangList = {
    [1] = "Chinese",
    [2] = "English",
    [3] = "French",
    [4] = "German",
    [5] = "Italian",
    [6] = "Korean",
    [7] = "Portuguese",
    [8] = "Russian",
    [9] = "Spanish",
}

addon.groupieRoleTable = {
    [1] = "Tank",
    [2] = "Healer",
    [3] = "Ranged DPS",
    [4] = "Melee DPS"
}

addon.groupieClassRoleTable = {
    ["DEATHKNIGHT"] = {
        [L["DeathKnight"].Blood] = { [1] = "Tank" },
        [L["DeathKnight"].Frost] = { [1] = "Tank", [4] = "Melee DPS" },
        [L["DeathKnight"].Unholy] = { [4] = "Melee DPS" }
    },
    ["DRUID"] = {
        [L["Druid"].Balance] = { [3] = "Ranged DPS" },
        [L["Druid"].Feral] = { [1] = "Tank", [4] = "Melee DPS" },
        [L["Druid"].Restoration] = { [2] = "Healer" }
    },
    ["HUNTER"] = {
        [L["Hunter"].BM] = { [3] = "Ranged DPS" },
        [L["Hunter"].MM] = { [3] = "Ranged DPS" },
        [L["Hunter"].Survival] = { [3] = "Ranged DPS" }
    },
    ["MAGE"] = {
        [L["Mage"].Arcane] = { [3] = "Ranged DPS" },
        [L["Mage"].Fire] = { [3] = "Ranged DPS" },
        [L["Mage"].Frost] = { [3] = "Ranged DPS" }
    },
    ["PALADIN"] = {
        [L["Paladin"].Holy] = { [2] = "Healer" },
        [L["Paladin"].Protection] = { [1] = "Tank" },
        [L["Paladin"].Retribution] = { [4] = "Melee DPS" }
    },
    ["PRIEST"] = {
        [L["Priest"].Discipline] = { [2] = "Healer" },
        [L["Priest"].Holy] = { [2] = "Healer" },
        [L["Priest"].Shadow] = { [3] = "Ranged DPS" }
    },
    ["ROGUE"] = {
        [L["Rogue"].Assassination] = { [4] = "Melee DPS" },
        [L["Rogue"].Combat] = { [4] = "Melee DPS" },
        [L["Rogue"].Subtlety] = { [4] = "Melee DPS" }
    },
    ["SHAMAN"] = {
        [L["Shaman"].Elemental] = { [3] = "Ranged DPS" },
        [L["Shaman"].Enhancement] = { [4] = "Melee DPS" },
        [L["Shaman"].Restoration] = { [2] = "Healer" }
    },
    ["WARLOCK"] = {
        [L["Warlock"].Affliction] = { [3] = "Ranged DPS" },
        [L["Warlock"].Demonology] = { [3] = "Ranged DPS" },
        [L["Warlock"].Destruction] = { [3] = "Ranged DPS" }
    },
    ["WARRIOR"] = {
        [L["Warrior"].Arms] = { [1] = "Tank", [4] = "Melee DPS" },
        [L["Warrior"].Fury] = { [4] = "Melee DPS" },
        [L["Warrior"].Protection] = { [1] = "Tank" }
    }
}

addon.groupieInstanceTypes = {
    "Wrath of the Lich King Heroic Raids - 25",
    "Wrath of the Lich King Heroic Raids - 10",
    "Wrath of the Lich King Raids - 25",
    "Wrath of the Lich King Raids - 10",
    "Wrath of the Lich King Heroic Dungeons",
    "Wrath of the Lich King Dungeons",
    "The Burning Crusade Raids",
    "The Burning Crusade Heroic Dungeons",
    "The Burning Crusade Dungeons",
    "Classic Raids",
    "Classic Dungeons",
}

--0 - Heroic
--1 - 10 Normal
--2 - 25 Normal
--3 - Heroic 10
--4 - Heroic 25
addon.groupieVersionPatterns = {
    ["h"] = 0,
    ["hc"] = 0,
    ["heroic"] = 0,
    ["heroics"] = 0,
    ["hero"] = 0,
    ["10"] = 1,
    ["n10"] = 1,
    ["10n"] = 1,
    ["10man"] = 1,
    ["10m"] = 1,
    ["25"] = 2,
    ["n25"] = 2,
    ["25n"] = 2,
    ["25man"] = 2,
    ["25m"] = 2,
    ["h10"] = 3,
    ["h10man"] = 3,
    ["h10m"] = 3,
    ["10h"] = 3,
    ["h25"] = 4,
    ["h25man"] = 4,
    ["h25m"] = 4,
    ["25h"] = 4,
}

--0 - Generic group
--1 - Looking for Tank
--2 - Looking for Healer
--3 - Looking for DPS
--4 - LFG
--5 - boost runs
addon.groupieLFPatterns = {
    ["group"] = 0,
    ["lf"] = 0,
    ["lfm"] = 0,
    ["run"] = 0,
    ["runs"] = 0,
    ["running"] = 0,

    ["lftank"] = 1,
    ["lftanks"] = 1,
    ["tank"] = 1,
    ["tanks"] = 1,

    ["lfheal"] = 2,
    ["lfhealer"] = 2,
    ["lfheals"] = 2,
    ["lfhealers"] = 2,
    ["heal"] = 2,
    ["heals"] = 2,
    ["healer"] = 2,
    ["healers"] = 2,

    ["lfdps"] = 3,
    ["dps"] = 3,
    ["melee"] = 3,
    ["ranged"] = 3,
    ["lfmelee"] = 3,
    ["lfranged"] = 3,

    ["lfg"] = 4,

    ["boost"] = 5,
    ["boosts"] = 5,
    ["boosting"] = 5,
    ["wts"] = 5,
}

addon.groupieUnflippedLootPatterns = {
    [L["Filters"].Loot_Styles.Ticket] = "ticket",
    [L["Filters"].Loot_Styles.GDKP] = "gdkp bid buyer",
    [L["Filters"].Loot_Styles.SoftRes] = "2sr 1sr sr softres softreserve soft",
    [L["Filters"].Loot_Styles.MSOS] = "msos",
    [L["Filters"].Loot_Styles.Other] = "afk boost boosting boosts exp mob mobs recruit recruiting recruits roster selling wts xp layer hire"
}

addon.lootTypeColors = {
    [L["Filters"].Loot_Styles.Ticket] = "FFC107",
    [L["Filters"].Loot_Styles.GDKP] = "4CAF50",
    [L["Filters"].Loot_Styles.SoftRes] = "9C27B0",
    [L["Filters"].Loot_Styles.MSOS] = "2196F3",
    [L["Filters"].Loot_Styles.Other] = "FFFFFF",
    [L["Filters"].Loot_Styles.PVP] = "F44336",
}

addon.classColors = {
    ["DEATHKNIGHT"] = "C41F3B",
    ["DRUID"] = "FF7D0A",
    ["HUNTER"] = "ABD473",
    ["MAGE"] = "69CCF0",
    ["MONK"] = "00FF96",
    ["PALADIN"] = "F58CBA",
    ["PRIEST"] = "FFFFFF",
    ["ROGUE"] = "FFF569",
    ["SHAMAN"] = "0070DE",
    ["WARLOCK"] = "9482C9",
    ["WARRIOR"] = "C79C6E",
}

addon.edgeCasePatterns = { "mt", "os", "up", "dk", "eye", "st", "mh", "an" }

--instanceVersions[instance] = {{size, isHeroic}, ...}
addon.instanceVersions = {
    ["Ragefire Chasm"]        = { { 5, false } },
    ["Wailing Caverns"]       = { { 5, false } },
    ["Deadmines"]             = { { 5, false } },
    ["Shadowfang Keep"]       = { { 5, false } },
    ["Stormwind Stockades"]   = { { 5, false } },
    ["Blackfathom Deeps"]     = { { 5, false } },
    ["Gnomeregan"]            = { { 5, false } },
    ["Razorfen Kraul"]        = { { 5, false } },
    ["Scarlet Graveyard"]     = { { 5, false } },
    ["Scarlet Library"]       = { { 5, false } },
    ["Scarlet Armory"]        = { { 5, false } },
    ["Scarlet Cathedral"]     = { { 5, false } },
    ["Razorfen Downs"]        = { { 5, false } },
    ["Uldaman"]               = { { 5, false } },
    ["Zul'Farrak"]            = { { 5, false } },
    ["Maraudon"]              = { { 5, false } },
    ["Sunken Temple"]         = { { 5, false } },
    ["Blackrock Depths"]      = { { 5, false } },
    ["Dire Maul East"]        = { { 5, false } },
    ["Dire Maul North"]       = { { 5, false } },
    ["Dire Maul West"]        = { { 5, false } },
    ["Lower Blackrock Spire"] = { { 5, false } },
    ["Stratholme"]            = { { 5, false } },
    ["Scholomance"]           = { { 5, false } },

    ["Upper Blackrock Spire"] = { { 10, false } },
    ["Zul'Gurub"]             = { { 20, false } },
    ["Ruins of Ahn'Qiraj"]    = { { 20, false } },
    ["Onyxia's Lair"]         = { { 40, false } },
    ["Molten Core"]           = { { 40, false } },
    ["Blackwing Lair"]        = { { 40, false } },
    ["Temple of Ahn'Qiraj"]   = { { 40, false } },
    --["Naxxramas"]             = { { 40, false } },

    ["Hellfire Ramparts"]       = { { 5, false }, { 5, true } },
    ["Blood Furnace"]           = { { 5, false }, { 5, true } },
    ["Slave Pens"]              = { { 5, false }, { 5, true } },
    ["Underbog"]                = { { 5, false }, { 5, true } },
    ["Mana-Tombs"]              = { { 5, false }, { 5, true } },
    ["Auchenai Crypts"]         = { { 5, false }, { 5, true } },
    ["Sethekk Halls"]           = { { 5, false }, { 5, true } },
    ["Old Hillsbrad Foothills"] = { { 5, false }, { 5, true } },
    ["Shadow Labyrinth"]        = { { 5, false }, { 5, true } },
    ["Mechanar"]                = { { 5, false }, { 5, true } },
    ["Shattered Halls"]         = { { 5, false }, { 5, true } },
    ["Steamvault"]              = { { 5, false }, { 5, true } },
    ["Botanica"]                = { { 5, false }, { 5, true } },
    ["Arcatraz"]                = { { 5, false }, { 5, true } },
    ["Black Morass"]            = { { 5, false }, { 5, true } },
    ["Magisters' Terrace"]      = { { 5, false }, { 5, true } },

    ["Karazhan"]             = { { 10, false } },
    ["Zul'Aman"]             = { { 10, false } },
    ["Gruul's Lair"]         = { { 25, false } },
    ["Magtheridon's Lair"]   = { { 25, false } },
    ["Serpentshrine Cavern"] = { { 25, false } },
    ["Tempest Keep"]         = { { 25, false } },
    ["Mount Hyjal"]          = { { 25, false } },
    ["Black Temple"]         = { { 25, false } },
    ["Sunwell Plateau"]      = { { 25, false } },

    ["Utgarde Keep"]          = { { 5, false }, { 5, true } },
    ["Nexus"]                 = { { 5, false }, { 5, true } },
    ["Azjol-Nerub"]           = { { 5, false }, { 5, true } },
    ["Old Kingdom"]           = { { 5, false }, { 5, true } },
    ["Drak'Tharon Keep"]      = { { 5, false }, { 5, true } },
    ["Violet Hold"]           = { { 5, false }, { 5, true } },
    ["Gundrak"]               = { { 5, false }, { 5, true } },
    ["Halls of Stone"]        = { { 5, false }, { 5, true } },
    ["Culling of Stratholme"] = { { 5, false }, { 5, true } },
    ["Halls of Lightning"]    = { { 5, false }, { 5, true } },
    ["Utgarde Pinnacle"]      = { { 5, false }, { 5, true } },
    ["Oculus"]                = { { 5, false }, { 5, true } },
    ["Trial of the Champion"] = { { 5, false }, { 5, true } },
    ["Forge of Souls"]        = { { 5, false }, { 5, true } },
    ["Pit of Saron"]          = { { 5, false }, { 5, true } },
    ["Halls of Reflection"]   = { { 5, false }, { 5, true } },

    ["Naxxramas"]         = { { 25, false }, { 10, false } },
    ["Obsidian Sanctum"]  = { { 25, false }, { 10, false } },
    ["Vault of Archavon"] = { { 25, false }, { 10, false } },
    ["Eye of Eternity"]   = { { 25, false }, { 10, false } },
    --["Onyxia's Lair"]        = { { 10, false }, { 25, false } },
    ["Ulduar"]            = { { 25, false }, { 10, false } },

    ["Trial of the Crusader"]       = { { 25, false }, { 10, false }, { 25, true }, { 10, true } },
    ["Icecrown Citadel"]            = { { 25, false }, { 10, false }, { 25, true }, { 10, true } },
    ["Ruby Sanctum"]                = { { 25, false }, { 10, false }, { 25, true }, { 10, true } },
    ["Trial of the Grand Crusader"] = { { 25, true }, { 10, true } },

    ["Coren Direbrew"]    = { { 5, false } },
    ["Ahune"]             = { { 5, false }, { 5, true } },
    ["Headless Horseman"] = { { 5, false } },
    ["Apothecary Hummel"] = { { 5, false } },
}

--Instance IDs from : https://wowpedia.fandom.com/wiki/InstanceID
addon.groupieInstanceData = {
    ["Heroic Ruby Sanctum - 25"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Raids - 25", InstanceID = 724, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3550, ActivityID = 1109, Icon = "RS.tga" },
    ["Heroic Icecrown Citadel - 25"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Raids - 25", InstanceID = 631, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3540, ActivityID = 1111, Icon = "ICC.tga" },
    ["Heroic Trial of the Grand Crusader - 25"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Raids - 25", InstanceID = 649, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3530, ActivityID = 1105, Icon = "TOC Raid.tga" },
    ["Heroic Ruby Sanctum - 10"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Raids - 10", InstanceID = 724, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3520, ActivityID = 1108, Icon = "RS.tga" },
    ["Heroic Icecrown Citadel - 10"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Raids - 10", InstanceID = 631, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3510, ActivityID = 1110, Icon = "ICC.tga" },
    ["Heroic Trial of the Grand Crusader - 10"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Raids - 10", InstanceID = 649, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3500, ActivityID = 1103, Icon = "TOC Raid.tga" },
    ["Ruby Sanctum - 25"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 25", InstanceID = 724, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3490, ActivityID = 1109, Icon = "RS.tga" },
    ["Icecrown Citadel - 25"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 25", InstanceID = 631, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3480, ActivityID = 1111, Icon = "ICC.tga" },
    ["Trial of the Crusader - 25"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 25", InstanceID = 649, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3470, ActivityID = 1104, Icon = "TOC Raid.tga" },
    ["Ulduar - 25"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 25", InstanceID = 603, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3460, ActivityID = 1107, Icon = "ULD.tga" },
    ["Onyxia's Lair - 25"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 25", InstanceID = 249, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3450, ActivityID = 1099, Icon = "ONY.tga" },
    ["Eye of Eternity - 25"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 25", InstanceID = 616, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3440, ActivityID = 1094, Icon = "EOE.tga" },
    ["Naxxramas - 25"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 25", InstanceID = 533, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3430, ActivityID = 1098, Icon = "NAX.tga" },
    ["Obsidian Sanctum - 25"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 25", InstanceID = 615, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3420, ActivityID = 1097, Icon = "OS.tga" },
    ["Vault of Archavon - 25"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 25", InstanceID = 624, MinLevel = 80, MaxLevel = 80,
        GroupSize = 25, Order = 3410, ActivityID = 1096, Icon = "VOA.tga" },
    ["Ruby Sanctum - 10"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 10", InstanceID = 724, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3400, ActivityID = 1108, Icon = "RS.tga" },
    ["Icecrown Citadel - 10"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 10", InstanceID = 631, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3390, ActivityID = 1110, Icon = "ICC.tga" },
    ["Trial of the Crusader - 10"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 10", InstanceID = 649, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3380, ActivityID = 1100, Icon = "TOC Raid.tga" },
    ["Ulduar - 10"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 10", InstanceID = 603, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3370, ActivityID = 1106, Icon = "ULD.tga" },
    ["Onyxia's Lair - 10"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 10", InstanceID = 249, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3360, ActivityID = 1156, Icon = "ONY.tga" },
    ["Eye of Eternity - 10"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 10", InstanceID = 616, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3350, ActivityID = 1102, Icon = "EOE.tga" },
    ["Obsidian Sanctum - 10"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 10", InstanceID = 615, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3340, ActivityID = 1101, Icon = "OS.tga" },
    ["Naxxramas - 10"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 10", InstanceID = 533, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3330, ActivityID = 841, Icon = "NAX.tga" },
    ["Vault of Archavon - 10"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Raids - 10", InstanceID = 624, MinLevel = 80, MaxLevel = 80,
        GroupSize = 10, Order = 3320, ActivityID = 1095, Icon = "VOA.tga" },
    ["Heroic Azjol-Nerub"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 601, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3310, ActivityID = 1121, Icon = "AN.tga" },
    ["Heroic Culling of Stratholme"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 595, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3300, ActivityID = 1126, Icon = "COS.tga" },
    ["Heroic Drak'Tharon Keep"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 600, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3290, ActivityID = 1129, Icon = "DTK.tga" },
    ["Heroic Forge of Souls"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 632, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3280, ActivityID = 1134, Icon = "FOS.tga" },
    ["Heroic Gundrak"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 604, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3270, ActivityID = 1130, Icon = "GUN.tga" },
    ["Heroic Halls of Lightning"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 602, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3260, ActivityID = 1127, Icon = "HOL.tga" },
    ["Heroic Halls of Reflection"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 668, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3250, ActivityID = 1136, Icon = "HOR.tga" },
    ["Heroic Halls of Stone"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 599, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3240, ActivityID = 1128, Icon = "HOS.tga" },
    ["Heroic Nexus"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 576, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3230, ActivityID = 1132, Icon = "NEX.tga" },
    ["Heroic Oculus"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 578, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3220, ActivityID = 1124, Icon = "OC.tga" },
    ["Heroic Old Kingdom"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 619, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3210, ActivityID = 1131, Icon = "OK.tga" },
    ["Heroic Pit of Saron"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 658, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3200, ActivityID = 1135, Icon = "PIT.tga" },
    ["Heroic Trial of the Champion"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 650, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3190, ActivityID = 1133, Icon = "TOC Dungeon.tga" },
    ["Heroic Utgarde Keep"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 574, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3180, ActivityID = 1122, Icon = "UK.tga" },
    ["Heroic Utgarde Pinnacle"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 575, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3170, ActivityID = 1125, Icon = "UP.tga" },
    ["Heroic Violet Hold"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Heroic Dungeons", InstanceID = 608, MinLevel = 80, MaxLevel = 80,
        GroupSize = 5, Order = 3160, ActivityID = 1123, Icon = "VH.tga" },
    ["Halls of Reflection"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Dungeons", InstanceID = 668, MinLevel = 80, MaxLevel = 80, GroupSize = 5,
        Order = 3150, ActivityID = 1080, Icon = "HOR.tga" },
    ["Forge of Souls"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Dungeons", InstanceID = 632, MinLevel = 78, MaxLevel = 80, GroupSize = 5,
        Order = 3140, ActivityID = 1078, Icon = "FOS.tga" },
    ["Pit of Saron"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Dungeons", InstanceID = 658, MinLevel = 78, MaxLevel = 80, GroupSize = 5,
        Order = 3130, ActivityID = 1079, Icon = "PIT.tga" },
    ["Trial of the Champion"] = { Active = false, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Dungeons", InstanceID = 650, MinLevel = 78, MaxLevel = 80, GroupSize = 5,
        Order = 3120, ActivityID = 1076, Icon = "TOC Dungeon.tga" },
    ["Culling of Stratholme"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Dungeons", InstanceID = 595, MinLevel = 78, MaxLevel = 80, GroupSize = 5,
        Order = 3110, ActivityID = 1065, Icon = "COS.tga" },
    ["Halls of Lightning"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Dungeons", InstanceID = 602, MinLevel = 78, MaxLevel = 80, GroupSize = 5,
        Order = 3100, ActivityID = 1068, Icon = "HOL.tga" },
    ["Oculus"] = { Active = true, Expac = "Wrath of the Lich King", InstanceType = "Wrath of the Lich King Dungeons",
        InstanceID = 578, MinLevel = 78, MaxLevel = 80, GroupSize = 5, Order = 3090, ActivityID = 1067, Icon = "OC.tga" },
    ["Utgarde Pinnacle"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Dungeons", InstanceID = 575, MinLevel = 78, MaxLevel = 80, GroupSize = 5,
        Order = 3080, ActivityID = 1075, Icon = "UP.tga" },
    ["Gundrak"] = { Active = true, Expac = "Wrath of the Lich King", InstanceType = "Wrath of the Lich King Dungeons",
        InstanceID = 604, MinLevel = 76, MaxLevel = 80, GroupSize = 5, Order = 3070, ActivityID = 1071, Icon = "GUN.tga" },
    ["Halls of Stone"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Dungeons", InstanceID = 599, MinLevel = 75, MaxLevel = 80, GroupSize = 5,
        Order = 3060, ActivityID = 1069, Icon = "HOS.tga" },
    ["Violet Hold"] = { Active = true, Expac = "Wrath of the Lich King", InstanceType = "Wrath of the Lich King Dungeons",
        InstanceID = 608, MinLevel = 73, MaxLevel = 78, GroupSize = 5, Order = 3050, ActivityID = 1073, Icon = "VH.tga" },
    ["Drak'Tharon Keep"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Dungeons", InstanceID = 600, MinLevel = 72, MaxLevel = 78, GroupSize = 5,
        Order = 3040, ActivityID = 1070, Icon = "DTK.tga" },
    ["Old Kingdom"] = { Active = true, Expac = "Wrath of the Lich King", InstanceType = "Wrath of the Lich King Dungeons",
        InstanceID = 619, MinLevel = 71, MaxLevel = 78, GroupSize = 5, Order = 3030, ActivityID = 1072, Icon = "OK.tga" },
    ["Azjol-Nerub"] = { Active = true, Expac = "Wrath of the Lich King", InstanceType = "Wrath of the Lich King Dungeons",
        InstanceID = 601, MinLevel = 70, MaxLevel = 77, GroupSize = 5, Order = 3020, ActivityID = 1066, Icon = "AN.tga" },
    ["Nexus"] = { Active = true, Expac = "Wrath of the Lich King", InstanceType = "Wrath of the Lich King Dungeons",
        InstanceID = 576, MinLevel = 70, MaxLevel = 75, GroupSize = 5, Order = 3010, ActivityID = 1077, Icon = "NEX.tga" },
    ["Utgarde Keep"] = { Active = true, Expac = "Wrath of the Lich King",
        InstanceType = "Wrath of the Lich King Dungeons", InstanceID = 574, MinLevel = 68, MaxLevel = 75, GroupSize = 5,
        Order = 3000, ActivityID = 1074, Icon = "UK.tga" },
    ["Sunwell Plateau"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Raids",
        InstanceID = 580, MinLevel = 70, MaxLevel = 70, GroupSize = 25, Order = 2400, ActivityID = 852, Icon = "SWP.tga" },
    ["Black Temple"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Raids",
        InstanceID = 564, MinLevel = 70, MaxLevel = 70, GroupSize = 25, Order = 2390, ActivityID = 850, Icon = "BT.tga" },
    ["Mount Hyjal"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Raids",
        InstanceID = 534, MinLevel = 70, MaxLevel = 70, GroupSize = 25, Order = 2380, ActivityID = 849, Icon = "MH.tga" },
    ["Tempest Keep"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Raids",
        InstanceID = 550, MinLevel = 70, MaxLevel = 70, GroupSize = 25, Order = 2370, ActivityID = 847, Icon = "TK.tga" },
    ["Serpentshrine Cavern"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Raids",
        InstanceID = 548, MinLevel = 70, MaxLevel = 70, GroupSize = 25, Order = 2360, ActivityID = 848, Icon = "SSC.tga" },
    ["Magtheridon's Lair"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Raids",
        InstanceID = 544, MinLevel = 70, MaxLevel = 70, GroupSize = 25, Order = 2350, ActivityID = 845, Icon = "MAG.tga" },
    ["Gruul's Lair"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Raids",
        InstanceID = 565, MinLevel = 70, MaxLevel = 70, GroupSize = 25, Order = 2340, ActivityID = 846,
        Icon = "GRUUL.tga" },
    ["Zul'Aman"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Raids",
        InstanceID = 568, MinLevel = 70, MaxLevel = 70, GroupSize = 10, Order = 2330, ActivityID = 851, Icon = "ZA.tga" },
    ["Karazhan"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Raids",
        InstanceID = 532, MinLevel = 70, MaxLevel = 70, GroupSize = 10, Order = 2320, ActivityID = 844, Icon = "KARA.tga" },
    ["Heroic Arcatraz"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 552, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2310, ActivityID = 915, Icon = "ARC.tga" },
    ["Heroic Auchenai Crypts"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 558, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2300, ActivityID = 903, Icon = "AC.tga" },
    ["Heroic Black Morass"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 269, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2290, ActivityID = 907, Icon = "BM.tga" },
    ["Heroic Blood Furnace"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 542, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2280, ActivityID = 912, Icon = "BF.tga" },
    ["Heroic Botanica"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 553, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2270, ActivityID = 918, Icon = "BOT.tga" },
    ["Heroic Hellfire Ramparts"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 543, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2260, ActivityID = 913, Icon = "RAMPS.tga" },
    ["Heroic Magisters' Terrace"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 585, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2250, ActivityID = 917, Icon = "MGT.tga" },
    ["Heroic Mana-Tombs"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 557, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2240, ActivityID = 904, Icon = "MT.tga" },
    ["Heroic Mechanar"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 554, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2230, ActivityID = 916, Icon = "MECH.tga" },
    ["Heroic Old Hillsbrad Foothills"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 560, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2220, ActivityID = 908, Icon = "OHB.tga" },
    ["Heroic Sethekk Halls"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 556, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2210, ActivityID = 905, Icon = "SETHEKK.tga" },
    ["Heroic Shadow Labyrinth"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 555, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2200, ActivityID = 906, Icon = "SL.tga" },
    ["Heroic Shattered Halls"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 540, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2190, ActivityID = 914, Icon = "SH.tga" },
    ["Heroic Slave Pens"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 547, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2180, ActivityID = 909, Icon = "SP.tga" },
    ["Heroic Steamvault"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 545, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2170, ActivityID = 910, Icon = "SV.tga" },
    ["Heroic Underbog"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Heroic Dungeons", InstanceID = 546, MinLevel = 70, MaxLevel = 72,
        GroupSize = 5, Order = 2160, ActivityID = 911, Icon = "UB.tga" },
    ["Magisters' Terrace"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Dungeons", InstanceID = 585, MinLevel = 69, MaxLevel = 72, GroupSize = 5,
        Order = 2150, ActivityID = 835, Icon = "MGT.tga" },
    ["Steamvault"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 545, MinLevel = 69, MaxLevel = 72, GroupSize = 5, Order = 2140, ActivityID = 822, Icon = "SV.tga" },
    ["Arcatraz"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 552, MinLevel = 69, MaxLevel = 72, GroupSize = 5, Order = 2130, ActivityID = 834, Icon = "ARC.tga" },
    ["Botanica"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 553, MinLevel = 69, MaxLevel = 75, GroupSize = 5, Order = 2120, ActivityID = 833, Icon = "BOT.tga" },
    ["Shadow Labyrinth"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 555, MinLevel = 69, MaxLevel = 72, GroupSize = 5, Order = 2110, ActivityID = 826, Icon = "SL.tga" },
    ["Shattered Halls"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 540, MinLevel = 69, MaxLevel = 72, GroupSize = 5, Order = 2100, ActivityID = 819, Icon = "SH.tga" },
    ["Black Morass"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 269, MinLevel = 68, MaxLevel = 72, GroupSize = 5, Order = 2090, ActivityID = 831, Icon = "BM.tga" },
    ["Mechanar"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 554, MinLevel = 68, MaxLevel = 72, GroupSize = 5, Order = 2080, ActivityID = 832, Icon = "MECH.tga" },
    ["Sethekk Halls"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 556, MinLevel = 66, MaxLevel = 72, GroupSize = 5, Order = 2070, ActivityID = 825,
        Icon = "SETHEKK.tga" },
    ["Old Hillsbrad Foothills"] = { Active = true, Expac = "The Burning Crusade",
        InstanceType = "The Burning Crusade Dungeons", InstanceID = 560, MinLevel = 66, MaxLevel = 72, GroupSize = 5,
        Order = 2060, ActivityID = 830, Icon = "OHB.tga" },
    ["Auchenai Crypts"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 558, MinLevel = 64, MaxLevel = 72, GroupSize = 5, Order = 2050, ActivityID = 824, Icon = "AC.tga" },
    ["Mana-Tombs"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 557, MinLevel = 63, MaxLevel = 71, GroupSize = 5, Order = 2040, ActivityID = 823, Icon = "MT.tga" },
    ["Underbog"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 546, MinLevel = 62, MaxLevel = 70, GroupSize = 5, Order = 2030, ActivityID = 821, Icon = "UB.tga" },
    ["Slave Pens"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 547, MinLevel = 61, MaxLevel = 69, GroupSize = 5, Order = 2020, ActivityID = 820, Icon = "SP.tga" },
    ["Blood Furnace"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 542, MinLevel = 60, MaxLevel = 68, GroupSize = 5, Order = 2010, ActivityID = 818, Icon = "BF.tga" },
    ["Hellfire Ramparts"] = { Active = true, Expac = "The Burning Crusade", InstanceType = "The Burning Crusade Dungeons",
        InstanceID = 543, MinLevel = 58, MaxLevel = 67, GroupSize = 5, Order = 2000, ActivityID = 817, Icon = "RAMPS.tga" },
    ["Naxxramas"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Raids", InstanceID = 533,
        MinLevel = 60, MaxLevel = 60, GroupSize = 40, Order = 1360, ActivityID = 0, Icon = "NAX.tga" },
    ["Temple of Ahn'Qiraj"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Raids",
        InstanceID = 531, MinLevel = 60, MaxLevel = 60, GroupSize = 40, Order = 1350, ActivityID = 843, Icon = "AQ40.tga" },
    ["Blackwing Lair"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Raids", InstanceID = 469,
        MinLevel = 60, MaxLevel = 60, GroupSize = 40, Order = 1340, ActivityID = 840, Icon = "BWL.tga" },
    ["Molten Core"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Raids", InstanceID = 409,
        MinLevel = 60, MaxLevel = 60, GroupSize = 40, Order = 1330, ActivityID = 839, Icon = "MC.tga" },
    ["Onyxia's Lair"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Raids", InstanceID = 249,
        MinLevel = 60, MaxLevel = 60, GroupSize = 40, Order = 1320, ActivityID = 838, Icon = "ONY.tga" },
    ["Ruins of Ahn'Qiraj"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Raids",
        InstanceID = 509, MinLevel = 60, MaxLevel = 60, GroupSize = 20, Order = 1310, ActivityID = 842, Icon = "AQ20.tga" },
    ["Zul'Gurub"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Raids", InstanceID = 309,
        MinLevel = 60, MaxLevel = 60, GroupSize = 20, Order = 1300, ActivityID = 836, Icon = "ZG.tga" },
    ["Upper Blackrock Spire"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Raids",
        InstanceID = 229, MinLevel = 60, MaxLevel = 60, GroupSize = 10, Order = 1290, ActivityID = 837, Icon = "UBRS.tga" },
    ["Dire Maul North"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 429, MinLevel = 56, MaxLevel = 61, GroupSize = 5, Order = 1230, ActivityID = 815, Icon = "DM.tga" },
    ["Dire Maul West"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 429, MinLevel = 56, MaxLevel = 61, GroupSize = 5, Order = 1220, ActivityID = 814, Icon = "DM.tga" },
    ["Scholomance"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons", InstanceID = 1007,
        MinLevel = 56, MaxLevel = 61, GroupSize = 5, Order = 1210, ActivityID = 797, Icon = "SCHOLO.tga" },
    ["Stratholme"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons", InstanceID = 329,
        MinLevel = 56, MaxLevel = 61, GroupSize = 5, Order = 1200, ActivityID = 816, Icon = "STRAT.tga" },
    ["Dire Maul East"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 429, MinLevel = 54, MaxLevel = 61, GroupSize = 5, Order = 1190, ActivityID = 813, Icon = "DM.tga" },
    ["Lower Blackrock Spire"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 229, MinLevel = 53, MaxLevel = 61, GroupSize = 5, Order = 1180, ActivityID = 812, Icon = "LBRS.tga" },
    ["Blackrock Depths"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 230, MinLevel = 48, MaxLevel = 60, GroupSize = 5, Order = 1170, ActivityID = 811, Icon = "BRD.tga" },
    ["Sunken Temple"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons", InstanceID = 109,
        MinLevel = 45, MaxLevel = 54, GroupSize = 5, Order = 1160, ActivityID = 810, Icon = "ST.tga" },
    ["Zul'Farrak"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons", InstanceID = 209,
        MinLevel = 42, MaxLevel = 50, GroupSize = 5, Order = 1150, ActivityID = 808, Icon = "ZF.tga" },
    ["Maraudon"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons", InstanceID = 349,
        MinLevel = 40, MaxLevel = 52, GroupSize = 5, Order = 1140, ActivityID = 809, Icon = "MARA.tga" },
    ["Scarlet Cathedral"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 1004, MinLevel = 36, MaxLevel = 44, GroupSize = 5, Order = 1130, ActivityID = 828, Icon = "SM.tga" },
    ["Uldaman"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons", InstanceID = 70,
        MinLevel = 36, MaxLevel = 44, GroupSize = 5, Order = 1120, ActivityID = 807, Icon = "ULDA.tga" },
    ["Razorfen Downs"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 129, MinLevel = 33, MaxLevel = 41, GroupSize = 5, Order = 1110, ActivityID = 806, Icon = "RFD.tga" },
    ["Scarlet Armory"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 1004, MinLevel = 33, MaxLevel = 41, GroupSize = 5, Order = 1100, ActivityID = 827, Icon = "SM.tga" },
    ["Scarlet Library"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 1004, MinLevel = 31, MaxLevel = 39, GroupSize = 5, Order = 1090, ActivityID = 829, Icon = "SM.tga" },
    ["Scarlet Graveyard"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 1004, MinLevel = 28, MaxLevel = 36, GroupSize = 5, Order = 1080, ActivityID = 805, Icon = "SM.tga" },
    ["Gnomeregan"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons", InstanceID = 90,
        MinLevel = 24, MaxLevel = 32, GroupSize = 5, Order = 1070, ActivityID = 803, Icon = "GNOMER.tga" },
    ["Razorfen Kraul"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons", InstanceID = 47,
        MinLevel = 23, MaxLevel = 31, GroupSize = 5, Order = 1060, ActivityID = 804, Icon = "RFK.tga" },
    ["Stormwind Stockades"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 34, MinLevel = 21, MaxLevel = 29, GroupSize = 5, Order = 1050, ActivityID = 802, Icon = "STOCKS.tga" },
    ["Blackfathom Deeps"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 48, MinLevel = 20, MaxLevel = 28, GroupSize = 5, Order = 1040, ActivityID = 801, Icon = "BFD.tga" },
    ["Shadowfang Keep"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 33, MinLevel = 17, MaxLevel = 25, GroupSize = 5, Order = 1030, ActivityID = 800, Icon = "SFK.tga" },
    ["Deadmines"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons", InstanceID = 36,
        MinLevel = 16, MaxLevel = 24, GroupSize = 5, Order = 1020, ActivityID = 799, Icon = "VC.tga" },
    ["Wailing Caverns"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 43, MinLevel = 16, MaxLevel = 24, GroupSize = 5, Order = 1010, ActivityID = 796, Icon = "WC.tga" },
    ["Ragefire Chasm"] = { Active = true, Expac = "World of Warcraft", InstanceType = "Classic Dungeons",
        InstanceID = 389, MinLevel = 13, MaxLevel = 20, GroupSize = 5, Order = 1000, ActivityID = 798, Icon = "RFC.tga" },
}

--For use in generating config controls, get all instance orders in order
addon.instanceOrders = {}
addon.instanceConfigData = {}
for key, val in pairs(addon.groupieInstanceData) do
    tinsert(addon.instanceOrders, val.Order)
    addon.instanceConfigData[val.Order] = {
        Name = key,
        InstanceType = val.InstanceType,
        MinLevel = val.MinLevel,
        MaxLevel = val.MaxLevel,
        GroupSize = val.GroupSize,
        IsHeroic = false
    }
    if strmatch(addon.instanceConfigData[val.Order].Name, "Heroic") then
        addon.instanceConfigData[val.Order].IsHeroic = true
    end
end
sort(addon.instanceOrders, function(a, b) return a > b end)

addon.groupieUnflippedDungeonPatterns = {
    ["Ragefire Chasm"]        = "rfc ragefire chasm",
    ["Wailing Caverns"]       = "wc wailing caverns",
    ["Deadmines"]             = "deadmines vc vancleef dead mines mine",
    ["Shadowfang Keep"]       = "sfk shadowfang",
    ["Stormwind Stockades"]   = "stk stock stockade stockades",
    ["Blackfathom Deeps"]     = "bfd blackfathom fathom",
    ["Gnomeregan"]            = "gnomer gnomeregan",
    ["Razorfen Kraul"]        = "rfk kraul",
    ["Scarlet Graveyard"]     = "smgy smg gy graveyard",
    ["Scarlet Library"]       = "smlib sml lib library",
    ["Scarlet Armory"]        = "smarm sma arm armory herod armoury arms",
    ["Scarlet Cathedral"]     = "smcath smc cath cathedral",
    ["Razorfen Downs"]        = "rfd downs",
    ["Uldaman"]               = "ulda uldaman",
    ["Zul'Farrak"]            = "zf zulfarrak farrak",
    ["Maraudon"]              = "mara maraudon princessrun princess",
    ["Sunken Temple"]         = "st sunken atal",
    ["Blackrock Depths"]      = "brd emperor emp",
    ["Dire Maul East"]        = "dme dmeast east puzilin jumprun",
    ["Dire Maul North"]       = "dmn dmnorth north tribute",
    ["Dire Maul West"]        = "dmw dmwest west",
    ["Lower Blackrock Spire"] = "lower lbrs lrbs",
    ["Stratholme"]            = "stratlive live living stratud undead ud baron stratholme stath stratholm strah strath strat starth",
    ["Scholomance"]           = "scholomance scholo sholo sholomance",

    ["Upper Blackrock Spire"] = "upper ubrs urbs rend",
    ["Zul'Gurub"]             = "zg gurub zulgurub",
    ["Ruins of Ahn'Qiraj"]    = "ruins aq20",
    ["Onyxia's Lair"]         = "onyxia ony",
    ["Molten Core"]           = "molten mc",
    ["Blackwing Lair"]        = "blackwing bwl",
    ["Temple of Ahn'Qiraj"]   = "aq40",
    ["Naxxramas"]             = "naxxramas nax naxx nx",

    ["Hellfire Ramparts"]       = "ramparts rampart ramp ramps",
    ["Blood Furnace"]           = "furnace furn bf",
    ["Slave Pens"]              = "slavepens pens sp",
    ["Underbog"]                = "underbog ub",
    ["Mana-Tombs"]              = "manatombs manatomb mana mt tomb tombs",
    ["Auchenai Crypts"]         = "crypts crypt auchenai ac acrypts acrypt",
    ["Sethekk Halls"]           = "sethekk seth anzu sethek",
    ["Old Hillsbrad Foothills"] = "ohb durnholde ohf",
    ["Shadow Labyrinth"]        = "sl slab labs labyrinth slabs",
    ["Mechanar"]                = "mech mechanar",
    ["Shattered Halls"]         = "sh shh shattered",
    ["Steamvault"]              = "sv steamvault steamvaults steam valts",
    ["Botanica"]                = "botanica bot",
    ["Arcatraz"]                = "arc arcatraz alcatraz",
    ["Black Morass"]            = "bm morass",
    ["Magisters' Terrace"]      = "mgt terrace magisters magister",

    ["Karazhan"]             = "kara karazhan karazan",
    ["Zul'Aman"]             = "za zulaman aman hsh", --hexshrunken head
    ["Gruul's Lair"]         = "gl gruul gruuls",
    ["Magtheridon's Lair"]   = "mag magtheridon magth mags",
    ["Serpentshrine Cavern"] = "ssc serpentshrine",
    ["Tempest Keep"]         = "tk tempest tempestkeep",
    ["Mount Hyjal"]          = "hyjal hs hyj mh",
    ["Black Temple"]         = "bt blacktemple glaive",
    ["Sunwell Plateau"]      = "swp sunwell plateau plataeu sunwel",

    ["Utgarde Keep"]          = "uk utgardekeep",
    ["Nexus"]                 = "nexus nex",
    ["Azjol-Nerub"]           = "an azjol nerub",
    ["Old Kingdom"]           = "ok atok ahnkahet ankahet kahet kingdom ak ank ahk",
    ["Drak'Tharon Keep"]      = "dtk tharon drak",
    ["Violet Hold"]           = "vh violet violethold",
    ["Gundrak"]               = "gundrak gd gdk",
    ["Halls of Stone"]        = "hos stone",
    ["Culling of Stratholme"] = "cos culling bronze",
    ["Halls of Lightning"]    = "hol lightning",
    ["Utgarde Pinnacle"]      = "up pinnacle",
    ["Oculus"]                = "oculus occulus oc occ ocu occu",
    --["Trial of the Champion"]      = "",
    ["Forge of Souls"]        = "forge fos forgeofsouls",
    ["Pit of Saron"]          = "pit pos pitofsaron",
    ["Halls of Reflection"]   = "hor reflection",

    --["Naxxramas"]            = "",
    ["Obsidian Sanctum"]  = "os obsidian obssanc obsanc obsidiansanctum os0d os1d os2d os3d",
    ["Vault of Archavon"] = "voa archavon vault",
    ["Eye of Eternity"]   = "eoe eye maly malygos",
    --["Onyxia's Lair"]        = "",
    ["Ulduar"]            = "uld uldu ulduar",

    ["TOC-SPECIALCASE"]             = "toc trial tocr",
    ["Icecrown Citadel"]            = "icc",
    ["Ruby Sanctum"]                = "rs rubysanctum rubysanc ruby halion",
    ["Trial of the Grand Crusader"] = "togc grand",

    ["Coren Direbrew"]    = "coren direbrew brewfest",
    ["Ahune"]             = "ahune",
    ["Headless Horseman"] = "headless horseman hh",
    ["Apothecary Hummel"] = "apothecary hummel loverocket chemical crownchemical chemicalco crownchemicalco",

    ["PVP"] = "2s 2v2 3s 3v3 5s 5v5 ab alterac arena arenas av basin challenger conquest cta duelist eots fta fth glad gladiator gulch gurubashi ioc premade PVP rival sota storm strand warsong wg wintergrasp wsg",
}


addon.groupieInstancePatterns = addon.TableFlip(addon.groupieUnflippedDungeonPatterns)
addon.groupieLootPatterns = addon.TableFlip(addon.groupieUnflippedLootPatterns)
addon.groupieLanguagePatterns = addon.TableFlip(addon.groupieUnflippedLanguagePatterns)

--Script to generate GUID for a player
--/run local name = UnitName("player"); local guid = UnitGUID("player"); ChatFrame1:AddMessage(name.." has the GUID: "..guid);
addon.GroupieDevs = {
    -- Groupie Team
    ["Player-4408-039B90A8"] = L["TeamMember"], -- Aevala-Faerlina
    ["Player-4800-048C8808"] = L["TeamMember"], -- Gogodeekay-Eranikus
    ["Player-4800-048C887A"] = L["TeamMember"], -- Gogodruid-Eranikus
    ["Player-4800-048C87ED"] = L["TeamMember"], -- Gogohunter-Eranikus
    ["Player-4800-048C88C6"] = L["TeamMember"], -- Gogomage-Eranikus
    ["Player-4800-048C88F0"] = L["TeamMember"], -- Gogopaladin-Eranikus
    ["Player-4800-048C87F8"] = L["TeamMember"], -- Gogopriest-Eranikus
    ["Player-4800-04942199"] = L["TeamMember"], -- Gogorogue-Eranikus
    ["Player-4800-048C8800"] = L["TeamMember"], -- Gogoshaman-Eranikus
    ["Player-4800-048C88CD"] = L["TeamMember"], -- Gogowarlock-Eranikus
    ["Player-4800-048C87E4"] = L["TeamMember"], -- Gogowarrior-Eranikus
    ["Player-4408-04867AC4"] = L["TeamMember"], -- Jarsjarsdk-Faerlina
    ["Player-4408-03AA25B2"] = L["TeamMember"], -- Kattz-Faerlina
    ["Player-4647-023571C6"] = L["TeamMember"], -- Kynura-Grobbulus
    ["Player-4467-02AB80C7"] = L["TeamMember"], -- Raegen-Firemaw

    -- Special Thanks
    -- TODO

    -- Test Accounts
    ["Player-4395-034E469C"] = L["TeamMember"], -- Cooltestguy-Benediction
}

addon.groupieAchievementPriorities = {
    ["Azjol-Nerub"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 491,
        [4] = 1288,
        [5] = 480,
    },
    ["Arcatraz"] = {
        [1] = 1287,
        [2] = 681,
        [3] = 1284,
        [4] = 660,
    },
    ["Auchenai Crypts"] = {
        [1] = 1287,
        [2] = 672,
        [3] = 1284,
        [4] = 666,
    },
    ["Black Morass"] = {
        [1] = 1287,
        [2] = 676,
        [3] = 1284,
        [4] = 655,
    },
    ["Black Temple"] = {
        [1] = 1286,
        [2] = 697,
    },
    ["Blackfathom Deeps"] = {
        [1] = 1283,
        [2] = 632,
    },
    ["Blackrock Depths"] = {
        [1] = 1283,
        [2] = 642,
    },
    ["Blackwing Lair"] = {
        [1] = 1285,
        [2] = 685,
    },
    ["Blood Furnace"] = {
        [1] = 1287,
        [2] = 668,
        [3] = 1284,
        [4] = 648,
    },
    ["Botanica"] = {
        [1] = 1287,
        [2] = 680,
        [3] = 1284,
        [4] = 659,
    },
    ["Culling of Stratholme"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 500,
        [4] = 1288,
        [5] = 479,
    },
    ["Deadmines"] = {
        [1] = 1283,
        [2] = 628,
    },
    ["Dire Maul North"] = {
        [1] = 1283,
        [2] = 644,
    },
    ["Dire Maul West"] = {
        [1] = 1283,
        [2] = 644,
    },
    ["Dire Maul East"] = {
        [1] = 1283,
        [2] = 644,
    },
    ["Drak'Tharon Keep"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 493,
        [4] = 1288,
        [5] = 482,
    },
    ["Eye of Eternity - 10"] = {
        [1] = 1400,
        [2] = 2138,
        [3] = 2137,
        [4] = 1870,
        [5] = 1869,
        [6] = 1875,
        [7] = 1874,
        [8] = 623,
        [9] = 622,
    },
    ["Eye of Eternity - 25"] = {
        [1] = 1400,
        [2] = 2138,
        [3] = 2137,
        [4] = 1870,
        [5] = 1869,
        [6] = 1875,
        [7] = 1874,
        [8] = 623,
        [9] = 622,
    },
    ["Forge of Souls"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 4519,
        [4] = 1288,
        [5] = 4516,
    },
    ["Gnomeregan"] = {
        [1] = 1283,
        [2] = 634,
    },
    ["Gruul's Lair"] = {
        [1] = 1286,
        [2] = 692,
    },
    ["Gundrak"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 495,
        [4] = 1288,
        [5] = 484,
    },
    ["Halls of Lightning"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 497,
        [4] = 1288,
        [5] = 486,
    },
    ["Halls of Reflection"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 4521,
        [4] = 1288,
        [5] = 4518,
    },
    ["Halls of Stone"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 496,
        [4] = 1288,
        [5] = 485,
    },
    ["Hellfire Ramparts"] = {
        [1] = 1287,
        [2] = 667,
        [3] = 1284,
        [4] = 647,
    },
    ["Heroic Azjol-Nerub"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 491,
        [4] = 1288,
        [5] = 480,
    },
    ["Heroic Arcatraz"] = {
        [1] = 1287,
        [2] = 681,
        [3] = 1284,
        [4] = 660,
    },
    ["Heroic Auchenai Crypts"] = {
        [1] = 1287,
        [2] = 672,
        [3] = 1284,
        [4] = 666,
    },
    ["Heroic Black Morass"] = {
        [1] = 1287,
        [2] = 676,
        [3] = 1284,
        [4] = 655,
    },
    ["Heroic Blood Furnace"] = {
        [1] = 1287,
        [2] = 668,
        [3] = 1284,
        [4] = 648,
    },
    ["Heroic Botanica"] = {
        [1] = 1287,
        [2] = 680,
        [3] = 1284,
        [4] = 659,
    },
    ["Heroic Culling of Stratholme"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 500,
        [4] = 1288,
        [5] = 500,
    },
    ["Heroic Drak'Tharon Keep"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 493,
        [4] = 1288,
        [5] = 482,
    },
    ["Heroic Forge of Souls"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 4519,
        [4] = 1288,
        [5] = 4516,
    },
    ["Heroic Gundrak"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 495,
        [4] = 1288,
        [5] = 484,
    },
    ["Heroic Halls of Lightning"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 497,
        [4] = 1288,
        [5] = 486,
    },
    ["Heroic Halls of Reflection"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 4521,
        [4] = 1288,
        [5] = 4518,
    },
    ["Heroic Halls of Stone"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 496,
        [4] = 1288,
        [5] = 485,
    },
    ["Heroic Hellfire Ramparts"] = {
        [1] = 1287,
        [2] = 667,
        [3] = 1284,
        [4] = 647,
    },
    ["Heroic Magisters' Terrace"] = {
        [1] = 1287,
        [2] = 682,
        [3] = 1284,
        [4] = 661,
    },
    ["Heroic Mana-Tombs"] = {
        [1] = 1287,
        [2] = 671,
        [3] = 1284,
        [4] = 651,
    },
    ["Heroic Mechanar"] = {
        [1] = 1287,
        [2] = 679,
        [3] = 1284,
        [4] = 658,
    },
    ["Heroic Nexus"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 490,
        [4] = 1288,
        [5] = 478,
    },
    ["Heroic Oculus"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 498,
        [4] = 1288,
        [5] = 487,
    },
    ["Heroic Old Hillsbrad Foothills"] = {
        [1] = 1287,
        [2] = 673,
        [3] = 1284,
        [4] = 652,
    },
    ["Heroic Old Kingdom"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 492,
        [4] = 1288,
        [5] = 481,
    },
    ["Heroic Pit of Saron"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 4520,
        [4] = 1288,
        [5] = 4517,
    },
    ["Heroic Sethekk Halls"] = {
        [1] = 1287,
        [2] = 674,
        [3] = 1284,
        [4] = 653,
    },
    ["Heroic Shadow Labyrinth"] = {
        [1] = 1287,
        [2] = 675,
        [3] = 1284,
        [4] = 654,
    },
    ["Heroic Shattered Halls"] = {
        [1] = 1287,
        [2] = 678,
        [3] = 1284,
        [4] = 657,
    },
    ["Heroic Slave Pens"] = {
        [1] = 1287,
        [2] = 669,
        [3] = 1284,
        [4] = 649,
    },
    ["Heroic Steamvault"] = {
        [1] = 1287,
        [2] = 677,
        [3] = 1284,
        [4] = 656,
    },
    ["Heroic Trial of the Champion"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 4297,
        [4] = 4298,
        [5] = 1288,
        [6] = 4296,
        [7] = 3778,
    },
    ["Heroic Underbog"] = {
        [1] = 1287,
        [2] = 670,
        [3] = 1284,
        [4] = 650,
    },
    ["Heroic Utgarde Keep"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 489,
        [4] = 1288,
        [5] = 477,
    },
    ["Heroic Utgarde Pinnacle"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 499,
        [4] = 1288,
        [5] = 488,
    },
    ["Heroic Violet Hold"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 494,
        [4] = 1288,
        [5] = 483,
    },
    ["Karazhan"] = {
        [1] = 1286,
        [2] = 690,
    },
    ["Lower Blackrock Spire"] = {
        [1] = 1283,
        [2] = 643,
    },
    ["Magisters' Terrace"] = {
        [1] = 1287,
        [2] = 682,
        [3] = 1284,
        [4] = 661,
    },
    ["Magtheridon's Lair"] = {
        [1] = 1286,
        [2] = 693,
    },
    ["Mana-Tombs"] = {
        [1] = 1287,
        [2] = 671,
        [3] = 1284,
        [4] = 651,
    },
    ["Maraudon"] = {
        [1] = 1283,
        [2] = 640,
    },
    ["Mechanar"] = {
        [1] = 1287,
        [2] = 679,
        [3] = 1284,
        [4] = 658,
    },
    ["Molten Core"] = {
        [1] = 1285,
        [2] = 686,
    },
    ["Mount Hyjal"] = {
        [1] = 1286,
        [2] = 695,
    },
    ["Naxxramas - 10"] = {
        [1] = 1402,
        [2] = 2138,
        [3] = 2137,
        [4] = 2186,
        [5] = 2187,
        [6] = 2177,
        [7] = 2176,
        [8] = 2139,
        [9] = 1996,
        [10] = 2147,
        [11] = 2146,
        [12] = 579,
        [13] = 578,
        [14] = 577,
        [15] = 575,
        [16] = 573,
        [17] = 576,
        [18] = 574,
        [19] = 572,
    },
    ["Naxxramas - 25"] = {
        [1] = 1402,
        [2] = 2138,
        [3] = 2137,
        [4] = 2186,
        [5] = 2187,
        [6] = 2177,
        [7] = 2176,
        [8] = 2139,
        [9] = 1996,
        [10] = 2147,
        [11] = 2146,
        [12] = 579,
        [13] = 578,
        [14] = 577,
        [15] = 575,
        [16] = 573,
        [17] = 576,
        [18] = 574,
        [19] = 572,
    },
    ["Nexus"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 490,
        [4] = 1288,
        [5] = 478,
    },
    ["Obsidian Sanctum - 10"] = {
        [1] = 456,
        [2] = 2138,
        [3] = 2137,
        [4] = 2054,
        [5] = 2051,
        [6] = 2053,
        [7] = 2050,
        [8] = 2052,
        [9] = 2049,
        [10] = 2048,
        [11] = 2047,
        [12] = 1877,
        [13] = 624,
        [14] = 625,
        [15] = 1876,
    },
    ["Obsidian Sanctum - 25"] = {
        [1] = 456,
        [2] = 2138,
        [3] = 2137,
        [4] = 2054,
        [5] = 2051,
        [6] = 2053,
        [7] = 2050,
        [8] = 2052,
        [9] = 2049,
        [10] = 2048,
        [11] = 2047,
        [12] = 1877,
        [13] = 624,
        [14] = 625,
        [15] = 1876,
    },
    ["Oculus"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 498,
        [4] = 1288,
        [5] = 487,
    },
    ["Old Hillsbrad Foothills"] = {
        [1] = 1287,
        [2] = 673,
        [3] = 1284,
        [4] = 652,
    },
    ["Old Kingdom"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 492,
        [4] = 1288,
        [5] = 481,
    },
    ["Onyxia's Lair - 10"] = {
        [1] = 4407,
        [2] = 4404,
        [3] = 4406,
        [4] = 4403,
        [5] = 4405,
        [6] = 4402,
        [7] = 4397,
        [8] = 4396,
    },
    ["Onyxia's Lair - 25"] = {
        [1] = 4407,
        [2] = 4404,
        [3] = 4406,
        [4] = 4403,
        [5] = 4405,
        [6] = 4402,
        [7] = 4397,
        [8] = 4396,
    },
    ["Pit of Saron"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 4520,
        [4] = 1288,
        [5] = 4517,
    },
    ["Ragefire Chasm"] = {
        [1] = 1283,
        [2] = 629,
    },
    ["Razorfen Downs"] = {
        [1] = 1283,
        [2] = 636,
    },
    ["Razorfen Kraul"] = {
        [1] = 1283,
        [2] = 635,
    },
    ["Ruins of Ahn'Qiraj"] = {
        [1] = 1285,
        [2] = 689,
    },
    ["Scarlet Graveyard"] = {
        [1] = 1283,
        [2] = 637,
    },
    ["Scarlet Cathedral"] = {
        [1] = 1283,
        [2] = 637,
    },
    ["Scarlet Library"] = {
        [1] = 1283,
        [2] = 637,
    },
    ["Scarlet Armory"] = {
        [1] = 1283,
        [2] = 637,
    },
    ["Scholomance"] = {
        [1] = 1283,
        [2] = 645,
    },
    ["Serpentshrine Cavern"] = {
        [1] = 1286,
        [2] = 694,
    },
    ["Sethekk Halls"] = {
        [1] = 1287,
        [2] = 674,
        [3] = 1284,
        [4] = 653,
    },
    ["Shadow Labyrinth"] = {
        [1] = 1287,
        [2] = 675,
        [3] = 1284,
        [4] = 654,
    },
    ["Shadowfang Keep"] = {
        [1] = 1283,
        [2] = 631,
    },
    ["Shattered Halls"] = {
        [1] = 1287,
        [2] = 678,
        [3] = 1284,
        [4] = 657,
    },
    ["Slave Pens"] = {
        [1] = 1287,
        [2] = 669,
        [3] = 1284,
        [4] = 649,
    },
    ["Steamvault"] = {
        [1] = 1287,
        [2] = 677,
        [3] = 1284,
        [4] = 656,
    },
    ["Stormwind Stockades"] = {
        [1] = 1283,
        [2] = 633,
    },
    ["Stratholme"] = {
        [1] = 1283,
        [2] = 646,
    },
    ["Sunken Temple"] = {
        [1] = 1283,
        [2] = 641,
    },
    ["Sunwell Plateau"] = {
        [1] = 1286,
        [2] = 698,
    },
    ["Tempest Keep"] = {
        [1] = 1286,
        [2] = 696,
    },
    ["Temple of Ahn'Qiraj"] = {
        [1] = 1285,
        [2] = 687,
    },
    ["Trial of the Champion"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 4297,
        [4] = 4298,
        [5] = 1288,
        [6] = 4296,
        [7] = 3778,
    },
    ["Uldaman"] = {
        [1] = 1283,
        [2] = 638,
    },
    ["Underbog"] = {
        [1] = 1287,
        [2] = 670,
        [3] = 1284,
        [4] = 650,
    },
    ["Utgarde Keep"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 489,
        [4] = 1288,
        [5] = 477,
    },
    ["Utgarde Pinnacle"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 499,
        [4] = 1288,
        [5] = 488,
    },
    ["Vault of Archavon - 10"] = {
        [1] = 4017,
        [2] = 4016,
        [3] = 4586,
        [4] = 4585,
        [5] = 3837,
        [6] = 3836,
        [7] = 3137,
        [8] = 3136,
        [9] = 1721,
        [10] = 1722,
    },
    ["Vault of Archavon - 25"] = {
        [1] = 4017,
        [2] = 4016,
        [3] = 4586,
        [4] = 4585,
        [5] = 3837,
        [6] = 3836,
        [7] = 3137,
        [8] = 3136,
        [9] = 1721,
        [10] = 1722,
    },
    ["Violet Hold"] = {
        [1] = 2136,
        [2] = 1289,
        [3] = 494,
        [4] = 1288,
        [5] = 483,
    },
    ["Wailing Caverns"] = {
        [1] = 1283,
        [2] = 630,
    },
    ["Zul'Aman"] = {
        [1] = 1286,
        [2] = 691,
    },
    ["Zul'Farrak"] = {
        [1] = 1283,
        [2] = 639,
    },
    ["Zul'Gurub"] = {
        [1] = 1285,
        [2] = 688,
    },
}
